pub enum EventType {
Update,
Delete,
VisibilityChange,
}Expand description
Event types for article changes.
The Realtime API streams events of these types as they happen. Event types indicate what kind of change occurred to an article.
Variants
Update
Article was created or updated (content changed)
Delete
Article was deleted
VisibilityChange
Article visibility changed (content/editor/comment hidden)