Module reference

Module reference 

Reference and citation types. Reference and citation types.

This module provides types for citations within article content and references (bibliographic entries) that citations link to.

Citations vs References

  • Citations: Markers in the text like “[3]” that link to references
  • References: Full bibliographic entries (books, websites, etc.)

Citations appear in crate::structured::Section and link to Reference entries in the article root.

Structs

Citation
Citation within content.
Reference
Reference/citation.
ReferenceText
Reference text content.

Enums

ReferenceType
Reference types.