Reference

Struct Reference 

pub struct Reference {
    pub identifier: String,
    pub group: Option<String>,
    pub reference_type: ReferenceType,
    pub metadata: Option<Value>,
    pub text: ReferenceText,
    pub source: Option<Value>,
    pub parent_reference: Option<String>,
}
Reference/citation.

A bibliographic reference that supports claims in the article. References have identifiers that link them to citations in the text.

Reference Types

  • web - Web-based sources
  • book - Book sources
  • text - Plain text (no template)

Example

Reference {
    identifier: "cite_note-36".to_string(),
    group: None,
    reference_type: ReferenceType::Web,
    metadata: Some(json!({
        "title": "Josephine Baker: Image & Icon",
        "url": "http://www.jazzreview.com/...",
    })),
    text: ReferenceText { ... },
    source: Some(json!({ ... })),
    parent_reference: None,
}

Fields

identifier: String

Reference identifier (links to citations)

group: Option<String>

Reference group (for grouped references)

reference_type: ReferenceType

Reference type

metadata: Option<Value>

Reference metadata (author, title, URL, etc.)

text: ReferenceText

Reference text content

source: Option<Value>

Reference source information

parent_reference: Option<String>

Parent reference identifier (for nested references)