pub struct InfoboxPart {
pub name: Option<String>,
pub part_type: InfoboxPartType,
pub value: Option<String>,
pub values: Option<Vec<String>>,
pub has_parts: Option<Vec<InfoboxPart>>,
pub links: Option<Vec<Link>>,
pub images: Option<Vec<Image>>,
}Expand description
Part of an infobox.
Infobox parts can be nested to create hierarchical data structures. For example, a taxobox might have sections for classification and characteristics.
Fields
name: Option<String>Part name
part_type: InfoboxPartTypePart type
value: Option<String>Single value (for field types)
values: Option<Vec<String>>Multiple values (for list type)
has_parts: Option<Vec<InfoboxPart>>Nested parts
links: Option<Vec<Link>>Links
images: Option<Vec<Image>>Images