pub struct Visibility {
pub text: bool,
pub editor: bool,
pub comment: bool,
}Expand description
Visibility flags for articles (present on visibility-change events).
When the editing community flags a revision as containing potentially damaging information, they change its visibility. The three booleans indicate whether the article body, editor name, or edit comment may contain harmful data.
Examples
use wme_models::Visibility;
let visibility = Visibility {
text: true,
editor: false,
comment: false,
};
// When text=false, the article content is hidden
// When editor=false, the editor name is hidden
// When comment=false, the edit summary is hiddenFields
text: boolIs article text visible?
editor: boolIs editor name visible?
comment: boolIs edit comment visible?